# SessionOverview

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project_id** | **str** |  | 
**project_name** | **str** |  | 
**session_id** | **str** |  | 
**active** | **bool** |  | 
**session_name** | **str** |  | 
**creator_email** | **str** |  | 
**price_per_h** | **float** |  | 
**price** | **float** |  | 
**total_h** | **float** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


